# Generated by Django 2.2.17 on 2021-01-15 10:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_circle', '0026_auto_20210115_1038'),
    ]

    operations = [
        migrations.AddField(
            model_name='circle',
            name='description',
            field=models.TextField(blank=True),
        ),
    ]
